@@ -160,7 +160,12 @@ def get_variable_type(documenter: Documenter) -> str:
 		annotations = {}
 
 	if documenter.objpath[-1] in annotations:
-		return format_annotation(annotations.get(documenter.objpath[-1]))
+		ann = annotations.get(documenter.objpath[-1])
+
+		if isinstance(ann, str):
+			return format_annotation(ann.strip("'\""))
+
+		return format_annotation(ann)
 	else:
 		# Instance attribute
 		key = ('.'.join(documenter.objpath[:-1]), documenter.objpath[-1])
@@ -282,6 +287,7 @@ class TypedAttributeDocumenter(AttributeDocumenter):
 	def __init__(self, directive: DocumenterBridge, name: str, indent: str = '') -> None:
 		super().__init__(directive=directive, name=name, indent=indent)
 		self.options = Options(self.options.copy())
+		self._datadescriptor = True
 
 	def add_directive_header(self, sig: str):
 		"""
